# Responsive helpers

ZSS provides mixins for using only breakpoints that are defined in the Sass map `$zss--breakpoints`.

## Source files

- [helpers/_responsive.scss](../../src/helpers/_responsive.scss)

## Mixins

### `media-until`  

Define CSS that’s only applied until the given breakpoint.

#### Parameters

- `$name`   
   The name of the breakpoint, as defined as a key in `$zss--breakpoints`.
- `$breakpoints`
   Optional Sass map, for using a different set of breakpoints.

### `media-between`  

Define CSS that’s only applied between the two given breakpoints.

#### Parameters

- `$min-name`   
   The name of the starting breakpoint, as defined as a key in `$zss--breakpoints`.
- `$max-name`   
   The name of the ending breakpoint, as defined as a key in `$zss--breakpoints`.
- `$breakpoints`
   Optional Sass map, for using a different set of breakpoints.

### `media-from`  

Define CSS that’s only applied from a given breakpoint and up.

#### Parameters

- `$name`   
   The name of the breakpoint, as defined as a key in `$zss--breakpoints`.
- `$breakpoints`
   Optional Sass map, for using a different set of breakpoints.

## Examples

```sass
.hodor {
    @include media-until(md) {
        background-color: get-color(red);
    }

    @include media-between(md, lg) {
        background-color: get-color(blue);
    }

    @include media-from(lg) {
        background-color: get-color(black);
    }
}

```